@@ -28,22 +28,19 @@ class BalconyServiceSummarizer(BaseBalconyApp,
         service=kwargs.get('service')
         balcony = BalconyAWS()
         service_node = balcony.get_service(service)
-        print(service_node)
-        services_resource_nodes = service_node.get_resource_nodes()
-        print(resource_nodes)
 
         read_only_function_count = 0
-        resource_nodes = []
-        for rn in services_resource_nodes:
+        generated_resource_nodes = []
+        for rn in service_node.get_resource_nodes():
             operation_names = rn.get_operation_names() 
-            resource_nodes.append({
+            generated_resource_nodes.append({
                 'name': rn.name,
                 'operation_names': operation_names
             })
             read_only_function_count += len(operation_names)
         return {
             'read_only_function_count':read_only_function_count,
-            'resource_nodes': resource_nodes
+            'resource_nodes': generated_resource_nodes
         } 
        
     def get_cli_app(self, *args, **kwargs) -> typer.main.Typer:
